twig/text
Values
pub fn line_break() -> twig.Content
Creates a paragraph break by inserting a double newline.
In Typst, two newlines create a new paragraph, similar to Markdown.
Example
Sequence([
strong([], [text("Hello")]),
line_break(),
emph([], [text("World")]),
])
pub fn text(s: String) -> twig.Content
Creates a plain text element.
Example
text("Hello, world!")
// -> "Hello, world!"